@@ -4,8 +4,11 @@ from .module_imports import *
 class ScanConfig:
     allowed_exts: Set[str]
     unallowed_exts: Set[str]
+    allowed_types: Set[str]
     exclude_types: Set[str]
+    allowed_dirs: List[str] = field(default_factory=list)
     exclude_dirs: List[str] = field(default_factory=list)
+    allowed_patterns: List[str] = field(default_factory=list)
     exclude_patterns: List[str] = field(default_factory=list)
 DEFAULT_ALLOWED_EXTS: Set[str] = {
     ".py", ".pyw",                             # python
@@ -37,3 +40,6 @@ DEFAULT_EXCLUDE_PATTERNS: Set[str] = {
 REMOTE_RE = re.compile(r"^(?P<host>[^:\s]+@[^:\s]+):(?P<path>/.*)$")
 AllowedPredicate = Optional[Callable[[str], bool]]
 DEFAULT_EXCLUDE_FILE_PATTERNS=DEFAULT_EXCLUDE_PATTERNS
+DEFAULT_ALLOWED_PATTENS="*"
+DEFAULT_ALLOWED_DIRS="*"
+DEFAULT_ALLOWED_TYPES="*"
