@@ -6,23 +6,17 @@
 # ============================================================
 
 
-import os
-import sys, importlib,os
-import sys, importlib, os, inspect
+from ...imports import *
 from pathlib import Path
-import os,sys
+
 
 
 
 from typing import *
-import re
 
 from typing import *
 from types import MethodType
-import os,re, sys, importlib, inspect, os, importlib.util, hashlib
-import os,tempfile,shutil,logging,ezodf,fnmatch,pytesseract,pdfplumber
-import pandas as pd
-import geopandas as gpd
+
 from datetime import datetime
 
 from typing import *
@@ -30,8 +24,6 @@ from werkzeug.utils import secure_filename
 from werkzeug.datastructures import FileStorage
 from pdf2image import convert_from_path   # only used for OCR fallback
 # ---- Core standard library modules -------------------------
-import os, sys, re, shlex, glob, platform, textwrap, subprocess, inspect, json, time
-import tempfile, shutil, logging, pathlib, fnmatch, importlib, importlib.util, types
 
 from datetime import datetime
 from types import ModuleType
@@ -44,18 +36,11 @@ from typing import (
 )
 
 # ---- Common 3rd-party dependencies --------------------------
-import pandas as pd
-import geopandas as gpd
-import pytesseract
-import pdfplumber
-import PyPDF2
-import ezodf
 from pdf2image import convert_from_path
 from werkzeug.utils import secure_filename
 from werkzeug.datastructures import FileStorage
 
 # ---- Helpers ------------------------------------------------
-import textwrap as tw
 from pprint import pprint
 
 # ============================================================
